==> webgui_7.9.18.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/Asset_MapPoint.pm <==
package WebGUI::i18n::German::Asset_MapPoint;
use utf8;
our $I18N = {
  'address1' => {
    'lastUpdated' => '1271849688',
    'message' => 'Erste Adresszeile'
  },
  'address1 description' => {
    'lastUpdated' => '1250972984',
    'message' => 'Erste Zeile der Adresse'
  },
  'address1 label' => {
    'lastUpdated' => '1250972954',
    'message' => 'Adresse 1'
  },
  'address2' => {
    'lastUpdated' => '1271849700',
    'message' => 'Zweite Adresszeile'
  },
  'address2 description' => {
    'lastUpdated' => '1250973002',
    'message' => 'Zweite Zeile der Adresse'
  },
  'address2 label' => {
    'lastUpdated' => '1250972962',
    'message' => 'Adresse 2'
  },
  'address3' => {
    'lastUpdated' => '1271849720',
    'message' => 'Dritte Adresszeile'
  },
  'assetName' => {
    'lastUpdated' => '1250972940',
    'message' => 'Kartenposition'
  },
  'city' => {
    'lastUpdated' => '1271849758',
    'message' => 'Die Stadt zu dieser Kartenposition'
  },
  'city description' => {
    'lastUpdated' => '1271850355',
    'message' => 'Ortsname zur Kartenposition'
  },
  'city label' => {
    'lastUpdated' => '1250972928',
    'message' => 'Ort'
  },
  'country' => {
    'lastUpdated' => '1271849777',
    'message' => 'Das Land zu dieser Kartenposition '
  },
  'country description' => {
    'lastUpdated' => '1250973043',
    'message' => 'Land zur Kartenposition'
  },
  'country label' => {
    'lastUpdated' => '1250972921',
    'message' => 'Land'
  },
  'currentPhoto' => {
    'lastUpdated' => '1272489375',
    'message' => 'Bild-Tag, das zum aktuell hochgeladenen Foto verlinkt.'
  },
  'edit template' => {
    'lastUpdated' => '1271850095',
    'message' => 'Template Kartenpunkt bearbeiten '
  },
  'email' => {
    'lastUpdated' => '1271849806',
    'message' => 'E-Mail-Adresse zu dieser Kartenposition'
  },
  'email description' => {
    'lastUpdated' => '1250973063',
    'message' => 'Emailadresse zur Kartenposition'
  },
  'email label' => {
    'lastUpdated' => '1250972913',
    'message' => 'Email'
  },
  'fax' => {
    'lastUpdated' => '1271849817',
    'message' => 'Faxnummer zu dieser Kartenposition'
  },
  'fax description' => {
    'lastUpdated' => '1250973075',
    'message' => 'Fax zur Kartenposition'
  },
  'fax label' => {
    'lastUpdated' => '1250972905',
    'message' => 'Fax'
  },
  'form_address1' => {
    'lastUpdated' => '1271850132',
    'message' => 'Textfeld zur Eingabe eines Adressteils'
  },
  'form_address2' => {
    'lastUpdated' => '1271850144',
    'message' => 'Textfeld zur Eingabe eines weiteren Adressteils'
  },
  'form_address3' => {
    'lastUpdated' => '1271850161',
    'message' => 'Textfeld zur Eingabe eines letzten Adressteils'
  },
  'form_city' => {
    'lastUpdated' => '1271850185',
    'message' => 'Textfeld zur Eingabe der Stadt der Adresse'
  },
  'form_country' => {
    'lastUpdated' => '1271850203',
    'message' => 'Textfeld zur Eingabe des (Bundes-)Landes der Adresse'
  },
  'form_email' => {
    'lastUpdated' => '1271850218',
    'message' => 'Textfeld zur Eingabe einer E-Mailadresse'
  },
  'form_fax' => {
    'lastUpdated' => '1271850239',
    'message' => 'Textfeld zur Eingabe einer Faxnummer'
  },
  'form_footer' => {
    'lastUpdated' => '1271850526',
    'message' => 'HTML-Code der das Bearbeitungsformular beendet'
  },
  'form_header' => {
    'lastUpdated' => '1271850538',
    'message' => 'HTML-Code der das Bearbeitungsformular startet'
  },
  'form_phone' => {
    'lastUpdated' => '1271850256',
    'message' => 'Textfeld zur Eingabe einer Telefonnummer'
  },
  'form_region' => {
    'lastUpdated' => '1271850642',
    'message' => 'Textfeld zur Eingabe von Land/Bezirk/Region/Staat zu dieser Adresse'
  },
  'form_storageIdPhoto' => {
    'lastUpdated' => '1271850811',
    'message' => 'Ein Datei-Formularfeld zum Upload eines Fotos mit Bezug zur Kartenposition'
  },
  'form_submit' => {
    'lastUpdated' => '1271850829',
    'message' => 'Button um das Formular abzusenden'
  },
  'form_synopsis' => {
    'lastUpdated' => '1271850707',
    'message' => 'Textarea-Feld zur Eingabe einer Zusammenfassung '
  },
  'form_title' => {
    'lastUpdated' => '1271850736',
    'message' => 'Textfeld zur Eingabe eines Titels'
  },
  'form_website' => {
    'lastUpdated' => '1271850758',
    'message' => 'Textfeld zur Eingabe einer URL mit Bezug zur Kartenposition'
  },
  'form_zipCode' => {
    'lastUpdated' => '1271850770',
    'message' => 'Textfeld zur Eingabe der PLZ'
  },
  'latitude' => {
    'lastUpdated' => '1271849920',
    'message' => 'Breitengrad dieser Kartenposition'
  },
  'latitude description' => {
    'lastUpdated' => '1250973101',
    'message' => 'Geografische Breite (Latitude) der Position'
  },
  'latitude label' => {
    'lastUpdated' => '1250972899',
    'message' => 'Geografische Breite'
  },
  'longitude' => {
    'lastUpdated' => '1271849940',
    'message' => 'Längengrad dieser Kartenposition'
  },
  'longitude description' => {
    'lastUpdated' => '1250973126',
    'message' => 'Geografische Länge (Longitude) der Kartenposition'
  },
  'longitude label' => {
    'lastUpdated' => '1250972887',
    'message' => 'Geografische Länge'
  },
  'map point asset template variables' => {
    'lastUpdated' => '1271850058',
    'message' => 'Template-Variablen Kartenpositions-Asset'
  },
  'phone' => {
    'lastUpdated' => '1271849846',
    'message' => 'Telefonnummer zu dieser Kartenposition'
  },
  'phone description' => {
    'lastUpdated' => '1250973141',
    'message' => 'Telefonnummer zur Position'
  },
  'phone label' => {
    'lastUpdated' => '1250972874',
    'message' => 'Telefon'
  },
  'region' => {
    'lastUpdated' => '1271849990',
    'message' => 'Land/Bezirk/Region/Staat zu dieser Kartenposition '
  },
  'state description' => {
    'lastUpdated' => '1250973154',
    'message' => 'Bundesland zur Kartenposition'
  },
  'state label' => {
    'lastUpdated' => '1250972863',
    'message' => 'Bundesland'
  },
  'storageIdPhoto' => {
    'lastUpdated' => '1271850020',
    'message' => 'Der Speicherort für diese Kartenposition'
  },
  'storageIdPhoto description' => {
    'lastUpdated' => '1250973187',
    'message' => 'Bild der Kartenposition'
  },
  'storageIdPhoto label' => {
    'lastUpdated' => '1250972851',
    'message' => 'Bild'
  },
  'website' => {
    'lastUpdated' => '1271849882',
    'message' => 'Website zu dieser Kartenposition'
  },
  'website description' => {
    'lastUpdated' => '1250973211',
    'message' => 'Eine Website URL'
  },
  'website label' => {
    'lastUpdated' => '1250972842',
    'message' => 'Website URL'
  },
  'zipCode' => {
    'lastUpdated' => '1271849867',
    'message' => 'PLZ zu dieser Kartenposition'
  },
  'zipCode description' => {
    'lastUpdated' => '1250973230',
    'message' => 'Postleitzahl zur Kartenposition'
  },
  'zipCode label' => {
    'lastUpdated' => '1250972832',
    'message' => 'Postleitzahl'
  }
}
;

1;

==> webgui_7.9.33.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/Asset_MapPoint.pm <==
package WebGUI::i18n::German::Asset_MapPoint;
use utf8;
our $I18N = {
  'address1' => {
    'lastUpdated' => '1271849688',
    'message' => 'Erste Adresszeile'
  },
  'address1 description' => {
    'lastUpdated' => '1250972984',
    'message' => 'Erste Zeile der Adresse'
  },
  'address1 label' => {
    'lastUpdated' => '1250972954',
    'message' => 'Adresse 1'
  },
  'address2' => {
    'lastUpdated' => '1271849700',
    'message' => 'Zweite Adresszeile'
  },
  'address2 description' => {
    'lastUpdated' => '1250973002',
    'message' => 'Zweite Zeile der Adresse'
  },
  'address2 label' => {
    'lastUpdated' => '1250972962',
    'message' => 'Adresse 2'
  },
  'address3' => {
    'lastUpdated' => '1271849720',
    'message' => 'Dritte Adresszeile'
  },
  'assetName' => {
    'lastUpdated' => '1250972940',
    'message' => 'Kartenposition'
  },
  'city' => {
    'lastUpdated' => '1271849758',
    'message' => 'Die Stadt zu dieser Kartenposition'
  },
  'city description' => {
    'lastUpdated' => '1271850355',
    'message' => 'Ortsname zur Kartenposition'
  },
  'city label' => {
    'lastUpdated' => '1250972928',
    'message' => 'Ort'
  },
  'country' => {
    'lastUpdated' => '1271849777',
    'message' => 'Das Land zu dieser Kartenposition '
  },
  'country description' => {
    'lastUpdated' => '1250973043',
    'message' => 'Land zur Kartenposition'
  },
  'country label' => {
    'lastUpdated' => '1250972921',
    'message' => 'Land'
  },
  'currentPhoto' => {
    'lastUpdated' => '1272489375',
    'message' => 'Bild-Tag, das zum aktuell hochgeladenen Foto verlinkt.'
  },
  'edit template' => {
    'lastUpdated' => '1271850095',
    'message' => 'Template Kartenpunkt bearbeiten '
  },
  'email' => {
    'lastUpdated' => '1271849806',
    'message' => 'E-Mail-Adresse zu dieser Kartenposition'
  },
  'email description' => {
    'lastUpdated' => '1250973063',
    'message' => 'Emailadresse zur Kartenposition'
  },
  'email label' => {
    'lastUpdated' => '1250972913',
    'message' => 'Email'
  },
  'fax' => {
    'lastUpdated' => '1271849817',
    'message' => 'Faxnummer zu dieser Kartenposition'
  },
  'fax description' => {
    'lastUpdated' => '1250973075',
    'message' => 'Fax zur Kartenposition'
  },
  'fax label' => {
    'lastUpdated' => '1250972905',
    'message' => 'Fax'
  },
  'form_address1' => {
    'lastUpdated' => '1271850132',
    'message' => 'Textfeld zur Eingabe eines Adressteils'
  },
  'form_address2' => {
    'lastUpdated' => '1271850144',
    'message' => 'Textfeld zur Eingabe eines weiteren Adressteils'
  },
  'form_address3' => {
    'lastUpdated' => '1271850161',
    'message' => 'Textfeld zur Eingabe eines letzten Adressteils'
  },
  'form_city' => {
    'lastUpdated' => '1271850185',
    'message' => 'Textfeld zur Eingabe der Stadt der Adresse'
  },
  'form_country' => {
    'lastUpdated' => '1271850203',
    'message' => 'Textfeld zur Eingabe des (Bundes-)Landes der Adresse'
  },
  'form_email' => {
    'lastUpdated' => '1271850218',
    'message' => 'Textfeld zur Eingabe einer E-Mailadresse'
  },
  'form_fax' => {
    'lastUpdated' => '1271850239',
    'message' => 'Textfeld zur Eingabe einer Faxnummer'
  },
  'form_footer' => {
    'lastUpdated' => '1271850526',
    'message' => 'HTML-Code der das Bearbeitungsformular beendet'
  },
  'form_header' => {
    'lastUpdated' => '1271850538',
    'message' => 'HTML-Code der das Bearbeitungsformular startet'
  },
  'form_phone' => {
    'lastUpdated' => '1271850256',
    'message' => 'Textfeld zur Eingabe einer Telefonnummer'
  },
  'form_region' => {
    'lastUpdated' => '1271850642',
    'message' => 'Textfeld zur Eingabe von Land/Bezirk/Region/Staat zu dieser Adresse'
  },
  'form_storageIdPhoto' => {
    'lastUpdated' => '1271850811',
    'message' => 'Ein Datei-Formularfeld zum Upload eines Fotos mit Bezug zur Kartenposition'
  },
  'form_submit' => {
    'lastUpdated' => '1271850829',
    'message' => 'Button um das Formular abzusenden'
  },
  'form_synopsis' => {
    'lastUpdated' => '1271850707',
    'message' => 'Textarea-Feld zur Eingabe einer Zusammenfassung '
  },
  'form_title' => {
    'lastUpdated' => '1271850736',
    'message' => 'Textfeld zur Eingabe eines Titels'
  },
  'form_website' => {
    'lastUpdated' => '1271850758',
    'message' => 'Textfeld zur Eingabe einer URL mit Bezug zur Kartenposition'
  },
  'form_zipCode' => {
    'lastUpdated' => '1271850770',
    'message' => 'Textfeld zur Eingabe der PLZ'
  },
  'latitude' => {
    'lastUpdated' => '1271849920',
    'message' => 'Breitengrad dieser Kartenposition'
  },
  'latitude description' => {
    'lastUpdated' => '1250973101',
    'message' => 'Geografische Breite (Latitude) der Position'
  },
  'latitude label' => {
    'lastUpdated' => '1250972899',
    'message' => 'Geografische Breite'
  },
  'longitude' => {
    'lastUpdated' => '1271849940',
    'message' => 'Längengrad dieser Kartenposition'
  },
  'longitude description' => {
    'lastUpdated' => '1250973126',
    'message' => 'Geografische Länge (Longitude) der Kartenposition'
  },
  'longitude label' => {
    'lastUpdated' => '1250972887',
    'message' => 'Geografische Länge'
  },
  'map point asset template variables' => {
    'lastUpdated' => '1271850058',
    'message' => 'Template-Variablen Kartenpositions-Asset'
  },
  'phone' => {
    'lastUpdated' => '1271849846',
    'message' => 'Telefonnummer zu dieser Kartenposition'
  },
  'phone description' => {
    'lastUpdated' => '1250973141',
    'message' => 'Telefonnummer zur Position'
  },
  'phone label' => {
    'lastUpdated' => '1250972874',
    'message' => 'Telefon'
  },
  'region' => {
    'lastUpdated' => '1271849990',
    'message' => 'Land/Bezirk/Region/Staat zu dieser Kartenposition '
  },
  'state description' => {
    'lastUpdated' => '1250973154',
    'message' => 'Bundesland zur Kartenposition'
  },
  'state label' => {
    'lastUpdated' => '1250972863',
    'message' => 'Bundesland'
  },
  'storageIdPhoto' => {
    'lastUpdated' => '1271850020',
    'message' => 'Der Speicherort für diese Kartenposition'
  },
  'storageIdPhoto description' => {
    'lastUpdated' => '1250973187',
    'message' => 'Bild der Kartenposition'
  },
  'storageIdPhoto label' => {
    'lastUpdated' => '1250972851',
    'message' => 'Bild'
  },
  'user defined variables' => {
    'lastUpdated' => '1298376580',
    'message' => 'Anders als das CollaborationSystem unterstützt MapPoint keine vordefinierten Felder für nutzerdefinierte Variablen. Stattdessen kann jede benötigte Art von Formularfeld erzeugt werden, dem Feld muss als gewünschte Bezeichnung die der Variable userDefined gegeben werden. WebGUI kümmert sich dann um die Speicherung.'
  },
  'userDefined1' => {
    'lastUpdated' => '1298376612',
    'message' => 'Der Wert des userDefined-Feldes 1'
  },
  'userDefined2' => {
    'lastUpdated' => '1298376618',
    'message' => 'Der Wert des userDefined-Feldes 2'
  },
  'userDefined3' => {
    'lastUpdated' => '1298376623',
    'message' => 'Der Wert des userDefined-Feldes 3'
  },
  'userDefined4' => {
    'lastUpdated' => '1298376629',
    'message' => 'Der Wert des userDefined-Feldes 4'
  },
  'userDefined5' => {
    'lastUpdated' => '1298376638',
    'message' => 'Der Wert des userDefined-Feldes 5'
  },
  'website' => {
    'lastUpdated' => '1271849882',
    'message' => 'Website zu dieser Kartenposition'
  },
  'website description' => {
    'lastUpdated' => '1250973211',
    'message' => 'Eine Website URL'
  },
  'website label' => {
    'lastUpdated' => '1250972842',
    'message' => 'Website URL'
  },
  'zipCode' => {
    'lastUpdated' => '1271849867',
    'message' => 'PLZ zu dieser Kartenposition'
  },
  'zipCode description' => {
    'lastUpdated' => '1250973230',
    'message' => 'Postleitzahl zur Kartenposition'
  },
  'zipCode label' => {
    'lastUpdated' => '1250972832',
    'message' => 'Postleitzahl'
  }
}
;

1;
